#!/bin/bash

# unmountmedia.sh
#
# Usage: unmountmedia.sh <mount point> <log file>
#
# mount point: the mount point for the media
#
# Return Codes:
# 1 - Error unmounting the media
#
# Author: C. Schuck
#
# Module History
#  00  01/22/2004  P. Provost - Changed to not look in mtab to do umount
#  01  03/16/2005  P. Provost - Changed back to look in mtab before unmount
#  02  03/17/2005  P. Provost - Fixed tracing
#  03  04/18/2005  P. Provost - Commented out sleep delay before unmounting
#  04  04/20/2005  P. Provost - Put sleep back because of intermittent unmount errors

MOUNTPOINT=$1
LOGFILE=$2

echo "-> unmountmedia.sh" >> $LOGFILE
echo "unmountmedia.sh: Unmounting media at $MOUNTPOINT for `date`" >> $LOGFILE

actzTrace "XMDA   T: -> unmountmedia.sh"
actzTrace "XMDA   F: unmountmedia.sh: Unmounting media at $MOUNTPOINT for `date`"

# Sleep for a few seconds to ensure that Java garbage collection occurs
# before the unmount is attemped. Otherwise, there may be some Java objects
# hanging around that reference paths to the media that can cause the umount
# command to fail with device busy errors. See MediaDevice.unmount()
# for the explicit call to Java garbage collector.  
sleep 3 

echo "unmountmedia.sh: checking /etc/mtab for mounted media at $MOUNTPOINT" >> $LOGFILE
actzTrace "XMDA   F: unmountmedia.sh: checking /etc/mtab for mounted media at $MOUNTPOINT"

echo "unmountmedia.sh: contents of /etc/mtab = " >> $LOGFILE
echo "" >> $LOGFILE
cat /etc/mtab >> $LOGFILE
echo "" >> $LOGFILE 

# Check to see if media is already mounted in /etc/mtab
if grep -q $MOUNTPOINT /etc/mtab; then 
    
    if ! umount -vf $MOUNTPOINT >> $LOGFILE 2>&1; then
       	
        echo "unmountmedia.sh: Couldn't unmount the media at $MOUNTPOINT... exiting" >> $LOGFILE
        actzTrace "XMDA   F: unmountmedia.sh: Couldn't unmount the media at $MOUNTPOINT...exiting."
        
        echo "<- unmountmedia.sh" >> $LOGFILE
        echo "" >> $LOGFILE
        
        actzTrace "XMDA   T: <- unmountmedia.sh"
       	
        exit 1
        
    fi
    
else # /etc/mtab says media not mounted
    
    echo "unmountmedia.sh: No media was found at $MOUNTPOINT in /etc/mtab" >> $LOGFILE
    actzTrace "XMDA   F: unmountmedia.sh: No media was found at $MOUNTPOINT in /etc/mtab"

fi

echo "<- unmountmedia.sh" >> $LOGFILE
echo "" >> $LOGFILE

actzTrace "XMDA   T: <- unmountmedia.sh"

exit 0
